;***********************************************************************
;Lista stalych i adresow zdefiniowanych dla komputera edukacyjnego 
;AVT-2250 dla rodziny procesorow MCS-51
;***********************************************************************

;=======================================================================
;Zdefiniowane znaki wyswietlacza.
;Wpisanie ktoregos z nich do bufora wyswietlacza powoduje zapalenie
;odpowiednich segmentow w ksztalcie danego znaku, np. komenda:
;			"  MOV  DL4,#_P  "
;powoduje pojawienie sie litery 'P' na 4-tej pozycji wyswietlacza
;kolejnosc segmentow w bajcie: 	
;			76543210
;			HGFEDCBA (msb...lsb)
;			--------
_0		equ	00111111b	;cyfra '0'
_1		equ	00000110b	;cyfra '1' 
_2		equ	01011011b	;cyfra '2'
_3		equ	01001111b	;cyfra '3'
_4		equ	01100110b	;cyfra '4'
_5		equ	01101101b	;cyfra '5'
_6		equ	01111101b	;cyfra '6'
_7		equ	00000111b	;cyfra '7'
_8		equ	01111111b	;cyfra '8'
_9		equ	01101111b	;cyfra '9'
_A		equ	01110111b	;litera 'A'
_B		equ	01111100b	;litera 'B'
_C		equ	00111001b	;litera 'C'
_D		equ	01011110b	;litera 'D'
_E		equ	01111001b	;litera 'E'
_F		equ	01110001b	;litera 'F'
_kropka		equ	10000000b	;maska kropki wyswietlacza
_pusty		equ	0		;wszystkie segmenty wygaszone

_minus		equ	01000000b	;znak '-'
_H		equ	01110110b	;litera 'H'
_J		equ	00011110b	;litera 'J'
_L		equ	00111000b	;litera 'L'
_P		equ	01110011b	;litera 'P'
_U		equ	00111110b	;litera 'U'
_Y		equ	01101110b	;litera 'Y'
_M		equ	00110111b	;znak podobny do duzej litery 'M'
_n		equ	01010100b	;znak podobny do malej litery 'n'
_T		equ	00110001b	;znak podobny do duzej litery 'T'
_r		equ	01010000b	;znak podobny do malego 'r'

;=======================================================================
;Kody przyporzadkowane poszczegolnym klawiszom po nacisnieciu ktoregos,
;uwaga: dla klawiszy '0'...'9','A'...'F' kody sa zgodne z ASCII, czyli
;wcisniecie klawisza 'A' powoduje pojawienie sie w buforze kodu ASCII
;tego klawisza czyli 65 (dziesietnie). Dla klawisza 'OK' przyporzadkowano
;kod specjalny:

klaw_OK		equ	 13		;kod klawisza Enter

;W ten sposob latwo jest testowac co akurat ostatnio nacisnieto, 
;odczytujac np. kod klawisza z bufora klawiatury za pomoca polecen:
;		"  MOV  A,klawisz   	;pobranie kodu z bufora do Acc
;		   XRL	A,#'6'	    	;czy wcisnieto klawisz '6' ?
;		   JZ	obsluga_6   	;tak to skocz do obslugi tego
;		   .... itd.		;klawisza	"

;=======================================================================
;Wartosci poczatkowe licznika T1 w trybie taktowania portu szeregowego
;wpisanie jednej z wybranych wartosci poleceniem:
;		"  mov  TH1,#b2400  "	;zmien predkosc na 2400 baud
;spowoduje zmiane predkosci transmisji asynchronicznej na 2400 bitow/sek

b1200		equ	0D0h		
b2400		equ	0E8h		
b4800		equ	0F4h	;wartosc poczatkowa monitora AVT-2250
b9600		equ	0FAh		
b19200		equ	0FDh		
b28800		equ	0FEh
b57600		equ	0FFh

;=======================================================================
;Adresy o specjalnym znaczeniu w zewnetrznej przestrzeni adresowej
;procesora dla systemu edukacyjnego AVT-2250

IO1		equ	04000h	;wyjscie Y2 dekodera U5 (schemat elektryczny)
IO2		equ	06000h	;j/w lecz Y3
IO3		equ	08000h	;j/w lecz Y4
IO4		equ	0A000h	;j/w lecz Y5

DSP_DATA	equ	IO1	;adres ukladu U8 - sterowanie segmentami 
				;wyswietlacza
DSP_POS		equ	04001h	;adres ukladu U10 - selektor aktualnie
				;zapalonej pozycji wyswietlacza
KEY_BUF		equ	IO2	;adres ukladu U12 - sprzetowy odczyt 
				;klawiatury

;=======================================================================
;Adresy 16 komorek wewnetrznej pamieci danych (RAM) procesora 80C51(52)
;zajete przez program monitora systemu edukacyjnego AVT-2250;
;uwaga: nieumiejetne modyfikowanie tych zmiennych moze spowodowac 
;zawieszenie sie systemu i koniecznosc jego zerowania - przycisk "RESET"

;programowy bufor wyswietlacz 8-pozycyjnego (DL1...DL8)

DL1		equ	78h	;komorka ze znakiem wyswietlanym na DL1
DL2		equ	79h	;j/w lecz na DL2
DL3		equ	7Ah	;j/w lecz na DL3
DL4		equ	7Bh	;j/w lecz na DL4
DL5		equ	7Ch	;j/w lecz na DL5
DL6		equ	7Dh	;j/w lecz na DL6
DL7		equ	7Eh	;j/w lecz na DL7
DL8		equ	7Fh	;j/w lecz na DL8

;---------------------------------------------------------------------------
;Licznik modulo 256 zwiekszany po kazdym wywolaniu obslugi przerwania 
;licznika T0; dla liczenia pozycji wyswietlacza (do 8-miu) wykorzystuje sie
;jego trzy najmlodsze jego bity

cnt256		equ	77h	

;---------------------------------------------------------------------------
;Komorka przechowujaca kod ostatnio wcisnietego klawisza - tzw.bufor
;klawiatury, uwaga: po zwolnieniu klawisza nie jest automatycznie zerowana !

klawisz		equ	76h		;bufor kodu nacisnietego klawisza

;---------------------------------------------------------------------------
;Licznik dla generowania opoznien przez procedure DELAY
;wpisanie do niego wartosci z zakresu 1...255 spowoduje zatrzymanie 
;wykonywania programu na czas = wartosc_wpisana * 1,953125 ms (okolo 2 ms)
;np. chcac w programie "poczekac" przez ok. 10 ms (milisekund) nalezy 
;wykonac instrukcje:	"  MOV	 A,#5		;bo 5 * 2 ms = 10 ms
;			   CALL  DELAY		;wywolanie proc. opoznienia
;			   .....itd.		;po ok. 10 ms powrot
;uwaga: ze wzgledu na blad opoznienia w zakresie 0...1,95 ms, w/w sposobu
;nie zaleca sie stosowac do generowania odstepow o duzej dokladnosci
;np. zegarowych

cntdel		equ	75h		

;---------------------------------------------------------------------------
;8-bitowy licznik liczacy od wartosci wpisanej do zera, wykorzystywany m.in.
;do okreslania faktu przeterminowania przy odbiorze znaku z portu szeregowego
;mozna go wykorzystywac do dodowlnych celow;
;zawsze wpisanie dowolnej wartosci z przedzialu 1...255 powoduje zmniejszanie 
;zawartosci co 1 sekunde az do osiagniecia wartosci 0, potem licznik stoi

overtime	equ	74h

;---------------------------------------------------------------------------
;Komorka przechowujaca czas przeterminowania (w sekundach) przy odbiorze 
;znaku z portu szeregowego; wartosc domyslna to liczba 60, czyli 60 sekund;
;wpisujac inna wartosc z zakresu 1...255 mozna ten czas modyfikowac;
;wartosc z tej komorki jest automatycznie przepisywana do zmiennej "overtime"
;po wywolaniu procedury INRS - odbierajacej znak z portu szeregowego

overconst	equ	73h

;---------------------------------------------------------------------------
;Komorka przechowujaca wartosc bardziej znaczacego bajtu, 16-bitowego adresu
;skoku do tablicy procedur obslugi przerwan zdefiniowanej przez Ciebie
;w przestrzeni adresowej procesora - zewnetrznej pamieci danych i programu
;uklad SRAM - U4; 
;wartosc wpisywana tu powinna byc z reguly rowna poczatkowemu segmentowi
;pamieci U4, ustawianej przez zwore JP3 - patrz schemat elektryczny systemu 
;AVT-2250

intvec		equ	72h

;---------------------------------------------------------------------------
;Komorka odpowiadajaca za migotanie poszczegolnych pozycji wyswietlacza;
;wpisanie do niej 8-bitowej liczby z ustawionymi bitami na odpowiednich
;pozycjach spowoduje migotanie odpowiadajacych im wyswietlaczy DL1...DL8
;np. polecenie:		"  MOV  blinks,#01000001b   "
;					 ^DL7  ^DL1
;spowoduje miganie wyswietlaczy DL1 (pierwszego) i DL7 (przedostatniego)

blinks		equ	71h

;---------------------------------------------------------------------------
;Komorka przechowujaca bajt specjalny monitora systemu AVT-2250, 
;tzw. 'Bios-Status-Word'

bsw		equ	70h		;Bios Status Word

;kolejnosc i znaczenie bitow jest nastepujace:
;w kolejnosci D7...D0:  int/extT0, extT0, x, x, 0.25Hz, 0.5Hz, 1Hz, 2Hz
;gdzie:	 bit 7: int/extT0 - ustawienie bitu spowoduje skok pod adres xx0Bh,
;			    gdzie xx to wartosc ze zmiennej 'intvec' (adr.72h),
;			    po wykonaniu procedury obslugi wyswietlacza i 
;			    i klawiatury monitora; pod tym adresem powinna
;			    znajdowac sie dalsza czesc tej procedury lub 
;			    instrukcja  " RETI  "
;	 bit 6: extT0     - ustawienie powoduje zaniechanie wykonywania
;			    obslugi wyswietlacza i klawiatury i skok pod adres
;			    w pamieci zewnetrznej rowny xx00h, gdzie xx to 
;			    wartosc ze zmiennej 'intvec' (adres 72h)
;			    bit ma wiekszy priorytet od bitu 'int/extT0'
;	 bity 5 i 4       - nie uzywane
;	 bit 3: 0.25Hz    - w przypadku gdy bit extT0 jest wyzerowany, bit ten
;			    zmienia swoja wartosc co 4 sekundy (0,25 Hz)
;	 bit 2: 0.5Hz     - j/w lecz co 2 sekundy   (0,5 Hz)
;	 bit 1: 1Hz       - j/w lecz co 1 sekunde   (1 Hz)
;	 bit 0: 2Hz       - j/w lecz co 0,5 sekundy (2 Hz)
